@@ -21,6 +21,7 @@ CLOUD_DEFAULTS = dict(
         region_name='region-b.geo-1',
         dns_service_type='hpext:dns',
         image_api_version='1',
+        image_format='qcow2',
     ),
     rackspace=dict(
         auth=dict(
@@ -29,5 +30,30 @@ CLOUD_DEFAULTS = dict(
         database_service_type='rax:database',
         compute_service_name='cloudServersOpenStack',
         image_api_version='2',
-    )
+        image_format='vhd',
+    ),
+    dreamhost=dict(
+        auth=dict(
+            auth_url='https://keystone.dream.io/v2.0',
+        ),
+        region_name='RegionOne',
+        image_api_version='2',
+        image_format='raw',
+    ),
+    vexxhost=dict(
+        auth=dict(
+            auth_url='http://auth.api.thenebulacloud.com:5000/v2.0/',
+        ),
+        region_name='ca-ymq-1',
+        image_api_version='1',
+        image_format='qcow2',
+    ),
+    runabove=dict(
+        auth=dict(
+            auth_url='https://auth.runabove.io/v2.0',
+        ),
+        image_api_version='1',
+        image_format='qcow2',
+    ),
+
 )
